Package 'kelaopendata'

Title: Access open data from National social insurance institution of Finland
Description: Designed to simplify and speed up access to open data from National social insurance institution of Finland (KELA) published at <https://avoindata.suomi.fi/data/fi/organization/kela>, the kelaopendata package offers researchers and analysts a set of tools to obtain data and metadata for a wide range of applications.
Authors: Markus Kainu
Maintainer: Markus Kainu <[email protected]>
License: Artistic-2.0 | file LICENSE
Version: 0.1.2
Built: 2026-05-07 08:15:57 UTC
Source: https://github.com/rOpenGov/kelaopendata

Help Index


Download a table and use optional sql filters

Description

Download a table and use optional sql filters

Usage

get_data(data_id, sql = NA)

Arguments

data_id

data id

sql

for filtering data NA if you want the whole data

Value

tibble


Download the whole data set using csv-files

Description

This is useful when your system has issues either with Arrow or Duckdb, or you only have internet access to original source avoindata.suomi.fi

Usage

get_data_csv(data_id)

Arguments

data_id

data id

Value

tibble


Download metadata

Description

Download metadata

Usage

get_metadata(data_id)

Arguments

data_id

data id

Value

list


List published data in avoindata.suomi.fi CKAN

Description

List published data in avoindata.suomi.fi CKAN

Usage

list_ckan(org = "Kansaneläkelaitos", n = 100)

Arguments

org

organisation to get listning from

n

number of hits

Value

data.frame


List datasets

Description

List datasets

Usage

list_datasets()

Value

data.frame


Get details from a package

Description

Get details from a package

Usage

pick_a_pkg(input_dataset = "a11f9ec3-669a-4242-bd30-f133a334901b")

Arguments

input_dataset

Value

list