| Title: | Access open data from National social insurance institution of Finland |
|---|---|
| Description: | Designed to simplify and speed up access to open data from National social insurance institution of Finland (KELA) published at <https://avoindata.suomi.fi/data/fi/organization/kela>, the kelaopendata package offers researchers and analysts a set of tools to obtain data and metadata for a wide range of applications. |
| Authors: | Markus Kainu |
| Maintainer: | Markus Kainu <[email protected]> |
| License: | Artistic-2.0 | file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-07 08:15:57 UTC |
| Source: | https://github.com/rOpenGov/kelaopendata |
Get links to csv files
get_csv_links(pkg_lst)get_csv_links(pkg_lst)
pkg_lst |
string
Download a table and use optional sql filters
get_data(data_id, sql = NA)get_data(data_id, sql = NA)
data_id |
data id |
sql |
for filtering data NA if you want the whole data |
tibble
This is useful when your system has issues either with Arrow or Duckdb, or you only have internet access to original source avoindata.suomi.fi
get_data_csv(data_id)get_data_csv(data_id)
data_id |
data id |
tibble
Download metadata
get_metadata(data_id)get_metadata(data_id)
data_id |
data id |
list
List published data in avoindata.suomi.fi CKAN
list_ckan(org = "Kansaneläkelaitos", n = 100)list_ckan(org = "Kansaneläkelaitos", n = 100)
org |
organisation to get listning from |
n |
number of hits |
data.frame
Get details from a package
pick_a_pkg(input_dataset = "a11f9ec3-669a-4242-bd30-f133a334901b")pick_a_pkg(input_dataset = "a11f9ec3-669a-4242-bd30-f133a334901b")
input_dataset |
list